PathBuilder

Struct PathBuilder 

pub struct PathBuilder { /* private fields */ }
A path builder.

Implementations

Source

impl PathBuilder

pub fn new() -> Self

pub fn move_to(&mut self, x: f32, y: f32) -> &mut Self

Begins a new contour.

pub fn line_to(&mut self, x: f32, y: f32) -> &mut Self

A straight segment to a point.

pub fn quad_to(&mut self, cx: f32, cy: f32, x: f32, y: f32) -> &mut Self

A quadratic Bézier curve.

pub fn cubic_to( &mut self, c1x: f32, c1y: f32, c2x: f32, c2y: f32, x: f32, y: f32, ) -> &mut Self

A cubic Bézier curve.

pub fn close(&mut self) -> &mut Self

Closes the current contour.

pub fn push_rect(&mut self, rect: Rect) -> &mut Self

Adds a rectangular contour (clockwise in screen coordinates).

pub fn push_round_rect(&mut self, rect: Rect, radius: f32) -> &mut Self

Adds a rectangle with rounded corners (cubic arcs).

radius is clamped to half of the shorter side. With a zero radius, a plain rectangle is added.

pub fn push_oval(&mut self, rect: Rect) -> &mut Self

Adds an ellipse inscribed in a rectangle using four cubic arcs.

pub fn push_circle(&mut self, cx: f32, cy: f32, r: f32) -> &mut Self

Adds a circle.

pub fn finish(self) -> Option<Path>

Finishes building and returns a Path. None if the path is empty.

pub fn from_rect(rect: Rect) -> Path

Quick creation of a rectangular path.

pub fn from_circle(cx: f32, cy: f32, r: f32) -> Option<Path>

Quick creation of a circle path.

pub fn from_round_rect(rect: Rect, radius: f32) -> Path

Quick creation of a rounded rectangle path.