pub struct PathBuilder { /* private fields */ }Expand description
A path builder.
Implementations
Sourceimpl PathBuilder
impl PathBuilder
pub fn new() -> Self
Sourcepub fn quad_to(&mut self, cx: f32, cy: f32, x: f32, y: f32) -> &mut Self
pub fn quad_to(&mut self, cx: f32, cy: f32, x: f32, y: f32) -> &mut Self
A quadratic Bézier curve.
Sourcepub fn cubic_to(
&mut self,
c1x: f32,
c1y: f32,
c2x: f32,
c2y: f32,
x: f32,
y: f32,
) -> &mut Self
pub fn cubic_to( &mut self, c1x: f32, c1y: f32, c2x: f32, c2y: f32, x: f32, y: f32, ) -> &mut Self
A cubic Bézier curve.
Sourcepub fn push_rect(&mut self, rect: Rect) -> &mut Self
pub fn push_rect(&mut self, rect: Rect) -> &mut Self
Adds a rectangular contour (clockwise in screen coordinates).
Sourcepub fn push_round_rect(&mut self, rect: Rect, radius: f32) -> &mut Self
pub fn push_round_rect(&mut self, rect: Rect, radius: f32) -> &mut Self
Adds a rectangle with rounded corners (cubic arcs).
radius is clamped to half of the shorter side. With a zero radius,
a plain rectangle is added.
Sourcepub fn push_oval(&mut self, rect: Rect) -> &mut Self
pub fn push_oval(&mut self, rect: Rect) -> &mut Self
Adds an ellipse inscribed in a rectangle using four cubic arcs.
Sourcepub fn push_circle(&mut self, cx: f32, cy: f32, r: f32) -> &mut Self
pub fn push_circle(&mut self, cx: f32, cy: f32, r: f32) -> &mut Self
Adds a circle.
Sourcepub fn finish(self) -> Option<Path>
pub fn finish(self) -> Option<Path>
Finishes building and returns a Path. None if the path is empty.
Sourcepub fn from_round_rect(rect: Rect, radius: f32) -> Path
pub fn from_round_rect(rect: Rect, radius: f32) -> Path
Quick creation of a rounded rectangle path.